@@ -220,12 +220,13 @@ void DebuggerDriver::writeCommand()
     m_activeCmd = cmd;
     TRACE("in writeCommand: " + cmd->m_cmdString);
 
-    const char* str = cmd->m_cmdString.local8Bit();
-    writeStdin(str, cmd->m_cmdString.local8Bit().length());
+    const char* str = cmd->m_cmdString.local8Bit().data();
+    size_t cmdStrLen = strlen(str);
+    writeStdin(str, cmdStrLen);
 
     // write also to log file
     if (m_logFile.isOpen()) {
-	m_logFile.writeBlock(str, cmd->m_cmdString.local8Bit().length());
+	m_logFile.writeBlock(str, cmdStrLen);
 	m_logFile.flush();
     }
 
