@@ -902,7 +902,7 @@ static ExprValue* parseVar(const char*& s)
 	while (isspace(*p))
 	    p++;
 	if (*p != '=') {
-	    TRACE(TQString().sprintf("parse error: = not found after %s", (const char*)name));
+	    TRACE(TQString().sprintf("parse error: = not found after %s", name));
 	    return 0;
 	}
 	// skip the '=' and more whitespace
@@ -2072,7 +2072,9 @@ bool GdbDriver::parseChangeExecutable(const char* output, TQString& message)
 	   strncmp(output, "Missing separate debuginfo", 26) == 0 ||
 	   strncmp(output, "Try: ", 5) == 0 ||
 	   strncmp(output, "Using host libthread_db", 23) == 0 ||
-	   strncmp(output, "(no debugging symbols found)", 28) == 0)
+	   strncmp(output, "(no debugging symbols found", 27) == 0 ||
+	   strncmp(output, "(No debugging symbols found", 27) == 0 ||
+	   strncmp(output, "warning: Loadable section", 25) == 0)
     {
 	// this line is good, go to the next one
 	const char* end = strchr(output, '\n');
