@@ -275,7 +275,7 @@ void SourceWindow::updateLineItems(const KDebugger* dbg)
     for (KDebugger::BrkptROIterator bp = dbg->breakpointsBegin(); bp != dbg->breakpointsEnd(); ++bp)
     {
 	if (fileNameMatches(bp->fileName)) {
-	    TRACE(TQString().sprintf("updating %s:%d", bp->fileName.data(), bp->lineNo));
+	    TRACE(TQString().sprintf("updating %s:%d", bp->fileName, bp->lineNo));
 	    int i = bp->lineNo;
 	    if (i < 0 || i >= int(m_sourceCode.size()))
 		continue;
